@@ -41,11 +41,18 @@ vlans:
     def setUp(self):
         super().setUp()
         self.topo = self.topo_class(
-            self.OVS_TYPE, self.ports_sock, self._test_name(), [self.dpid],
-            n_tagged=self.N_TAGGED, n_untagged=self.N_UNTAGGED,
-            n_extended=self.N_EXTENDED, e_cls=self.EXTENDED_CLS,
-            tmpdir=self.tmpdir, links_per_host=self.LINKS_PER_HOST,
-            hw_dpid=self.hw_dpid)
+            self.OVS_TYPE,
+            self.ports_sock,
+            self._test_name(),
+            [self.dpid],
+            n_tagged=self.N_TAGGED,
+            n_untagged=self.N_UNTAGGED,
+            n_extended=self.N_EXTENDED,
+            e_cls=self.EXTENDED_CLS,
+            tmpdir=self.tmpdir,
+            links_per_host=self.LINKS_PER_HOST,
+            hw_dpid=self.hw_dpid,
+        )
         self.start_net()
 
     def test_ping_all(self):
@@ -58,25 +65,27 @@ class FaucetTcpdumpHelperTest(FaucetSimpleTest):
 
     def _terminate_with_zero(self, tcpdump_helper):
         term_returns = tcpdump_helper.terminate()
-        self.assertEqual(
-            0, term_returns, msg=f'terminate code not 0: {term_returns}')
+        self.assertEqual(0, term_returns, msg="terminate code not 0: %d" % term_returns)
 
     def _terminate_with_nonzero(self, tcpdump_helper):
         term_returns = tcpdump_helper.terminate()
         self.assertNotEqual(
-            0, term_returns, msg=f'terminate code is 0: {term_returns}')
+            0, term_returns, msg="terminate code is 0: %d" % term_returns
+        )
 
     def test_tcpdump_execute(self):
         """Check tcpdump filter monitors ping using execute"""
         self.ping_all_when_learned()
         from_host = self.net.hosts[0]
         to_host = self.net.hosts[1]
-        tcpdump_filter = ('icmp')
-        tcpdump_helper = TcpdumpHelper(to_host, tcpdump_filter, [
-            lambda: from_host.cmd(f'ping -c1 {to_host.IP()}')])
+        tcpdump_filter = "icmp"
+        tcpdump_helper = TcpdumpHelper(
+            to_host,
+            tcpdump_filter,
+            [lambda: from_host.cmd("ping -c1 %s" % to_host.IP())],
+        )
         tcpdump_txt = tcpdump_helper.execute()
-        self.assertTrue(re.search(
-            f'{to_host.IP()}: ICMP echo request', tcpdump_txt))
+        self.assertTrue(re.search("%s: ICMP echo request" % to_host.IP(), tcpdump_txt))
         self._terminate_with_zero(tcpdump_helper)
 
     def test_tcpdump_pcap(self):
@@ -84,31 +93,37 @@ class FaucetTcpdumpHelperTest(FaucetSimpleTest):
         self.ping_all_when_learned()
         from_host = self.net.hosts[0]
         to_host = self.net.hosts[1]
-        tcpdump_filter = ('icmp')
-        pcap_file = os.path.join(self.tmpdir, 'out.pcap')
+        tcpdump_filter = "icmp"
+        pcap_file = os.path.join(self.tmpdir, "out.pcap")
         tcpdump_helper = TcpdumpHelper(
-            to_host, tcpdump_filter,
-            [lambda: from_host.cmd(f'ping -c3 {to_host.IP()}')],
-            pcap_out=pcap_file, packets=None)
+            to_host,
+            tcpdump_filter,
+            [lambda: from_host.cmd("ping -c3 %s" % to_host.IP())],
+            pcap_out=pcap_file,
+            packets=None,
+        )
         tcpdump_helper.execute()
         self._terminate_with_zero(tcpdump_helper)
-        result = from_host.cmd(f'tcpdump -en -r {pcap_file}')
-        self.assertEqual(result.count('ICMP echo reply'), 3, 'three icmp echo replies')
+        result = from_host.cmd("tcpdump -en -r %s" % pcap_file)
+        self.assertEqual(result.count("ICMP echo reply"), 3, "three icmp echo replies")
 
     def test_tcpdump_noblock(self):
         """Check tcpdump uses nonblocking next_line"""
         self.ping_all_when_learned()
         from_host = self.net.hosts[0]
         to_host = self.net.hosts[1]
-        tcpdump_filter = ('icmp')
+        tcpdump_filter = "icmp"
         tcpdump_helper = TcpdumpHelper(
-            to_host, tcpdump_filter,
-            [lambda: from_host.cmd(f'ping -c10 {to_host.IP()}')],
-            blocking=False, packets=None)
+            to_host,
+            tcpdump_filter,
+            [lambda: from_host.cmd("ping -c10 %s" % to_host.IP())],
+            blocking=False,
+            packets=None,
+        )
         count = 0
         while tcpdump_helper.next_line():
             count = count + 1
-            self.assertTrue(count < 10, 'Too many ping results before noblock')
+            self.assertTrue(count < 10, "Too many ping results before noblock")
         self._terminate_with_nonzero(tcpdump_helper)
 
     def test_tcpdump_nextline(self):
@@ -116,17 +131,24 @@ class FaucetTcpdumpHelperTest(FaucetSimpleTest):
         self.ping_all_when_learned()
         from_host = self.net.hosts[0]
         to_host = self.net.hosts[1]
-        tcpdump_filter = ('icmp')
-        tcpdump_helper = TcpdumpHelper(to_host, tcpdump_filter, [
-            lambda: from_host.cmd(f'ping -c5 -i2 {to_host.IP()}')])
+        tcpdump_filter = "icmp"
+        tcpdump_helper = TcpdumpHelper(
+            to_host,
+            tcpdump_filter,
+            [lambda: from_host.cmd("ping -c5 -i2 %s" % to_host.IP())],
+        )
 
-        self.assertTrue(re.search('proto ICMP', tcpdump_helper.next_line()))
+        self.assertTrue(re.search("proto ICMP", tcpdump_helper.next_line()))
         next_line = tcpdump_helper.next_line()
-        self.assertTrue(re.search(f'{to_host.IP()}: ICMP echo request', next_line), next_line)
-        self.assertTrue(re.search('proto ICMP', tcpdump_helper.next_line()))
+        self.assertTrue(
+            re.search("%s: ICMP echo request" % to_host.IP(), next_line), next_line
+        )
+        self.assertTrue(re.search("proto ICMP", tcpdump_helper.next_line()))
         next_line = tcpdump_helper.next_line()
-        self.assertTrue(re.search(f'{from_host.IP()}: ICMP echo reply', next_line), next_line)
-        self.assertFalse(re.search('ICMP', tcpdump_helper.next_line()))
+        self.assertTrue(
+            re.search("%s: ICMP echo reply" % from_host.IP(), next_line), next_line
+        )
+        self.assertFalse(re.search("ICMP", tcpdump_helper.next_line()))
         while tcpdump_helper.next_line():
             pass
         self._terminate_with_zero(tcpdump_helper)
@@ -137,7 +159,7 @@ class FaucetDockerHostTest(FaucetSimpleTest):
 
     N_UNTAGGED = 2
     N_EXTENDED = 2
-    EXTENDED_CLS = make_docker_host('faucet/test-host', startup_timeout_ms=90 * 1e3)
+    EXTENDED_CLS = make_docker_host("faucet/test-host", startup_timeout_ms=90 * 1e3)
 
     def test_containers(self):
         """Test containers to make sure they're actually docker."""
@@ -145,8 +167,8 @@ class FaucetDockerHostTest(FaucetSimpleTest):
         host_name = None
 
         for host in self.net.hosts:
-            marker = host.cmd('cat /root/test_marker.txt').strip()
-            if marker == 'faucet-test-host':
+            marker = host.cmd("cat /root/test_marker.txt").strip()
+            if marker == "faucet-test-host":
                 host_name = host.name
                 count = count + 1
                 host.activate()
@@ -154,15 +176,16 @@ class FaucetDockerHostTest(FaucetSimpleTest):
 
         self.assertTrue(
             count == self.N_EXTENDED,
-            f'Found {count} containers, expected {self.N_EXTENDED}')
+            "Found %d containers, expected %d" % (count, self.N_EXTENDED),
+        )
 
         self.assertTrue(
-            os.path.exists(
-                os.path.join(self.tmpdir, host_name, 'tmp')),
-            'container tmp dir missing')
+            os.path.exists(os.path.join(self.tmpdir, host_name, "tmp")),
+            "container tmp dir missing",
+        )
 
-        host_log = os.path.join(self.tmpdir, host_name, 'activate.log')
-        with open(host_log, 'r', encoding='utf-8') as host_log_file:
+        host_log = os.path.join(self.tmpdir, host_name, "activate.log")
+        with open(host_log, "r", encoding="utf-8") as host_log_file:
             lines = host_log_file.readlines()
-            output = ' '.join(lines).strip()
-            self.assertEqual(output, 'hello faucet')
+            output = " ".join(lines).strip()
+            self.assertEqual(output, "hello faucet")
