@@ -63,26 +63,29 @@ class FaucetEventNotifier:
     def start(self):
         """Start socket server."""
         if self.socket_path:
-            stream_server = StreamServer((self.socket_path, None), self._loop).serve_forever
+            stream_server = StreamServer(
+                (self.socket_path, None), self._loop
+            ).serve_forever
             self.thread = hub.spawn(stream_server)
-            self.thread.name = 'event'
+            self.thread.name = "event"
         return self.thread
 
     def _loop(self, sock, _addr):
         """Serve events."""
         with self.lock.acquire_nonblock() as result:
             if not result:
-                self.logger.info('multiple event clients not supported')
+                self.logger.info("multiple event clients not supported")
             else:
-                self.logger.info('event client connected')
+                self.logger.info("event client connected")
                 while True:
                     event = self.event_q.get()
                     event_bytes = bytes(
-                        '\n'.join((json.dumps(event, default=str), '')).encode('UTF-8'))
+                        "\n".join((json.dumps(event, default=str), "")).encode("UTF-8")
+                    )
                     try:
                         sock.sendall(event_bytes)
                     except (socket.error, IOError) as err:
-                        self.logger.info('event client disconnected: %s', err)
+                        self.logger.info("event client disconnected: %s", err)
                         break
         try:
             sock.close()
@@ -90,7 +93,7 @@ class FaucetEventNotifier:
             pass
 
     def get_event(self):
-        assert self.thread is None, 'not allowed with async _loop'
+        assert self.thread is None, "not allowed with async _loop"
         return None if self.event_q.empty() else self.event_q.get()
 
     def notify(self, dp_id, dp_name, event_dict):
@@ -98,16 +101,16 @@ class FaucetEventNotifier:
         assert isinstance(event_dict, dict)
         self.event_id += 1
         event = {
-            'version': 1,
-            'time': time.time(),
-            'dp_id': dp_id,
-            'dp_name': dp_name,
-            'event_id': self.event_id,
+            "version": 1,
+            "time": time.time(),
+            "dp_id": dp_id,
+            "dp_name": dp_name,
+            "event_id": self.event_id,
         }
         for header_key in list(event):
             assert header_key not in event_dict
         event.update(event_dict)
-        self.metrics.faucet_event_id.set(event['event_id'])
+        self.metrics.faucet_event_id.set(event["event_id"])
         if self.event_q.full():
             self.event_q.get()
         self.event_q.put(event)
@@ -122,18 +125,20 @@ class FaucetEventNotifier:
         if not os.path.exists(socket_dir):
             try:
                 os.makedirs(socket_dir)
-            except (PermissionError) as err:  # pytype: disable=name-error
-                self.logger.error('Unable to create event socket directory: %s', err)
+            except PermissionError as err:  # pytype: disable=name-error
+                self.logger.error("Unable to create event socket directory: %s", err)
                 return None
         # Check directory permissions.
         if not os.access(socket_dir, os.R_OK | os.W_OK | os.X_OK):
-            self.logger.error('Incorrect permissions set on socket directory %s', socket_dir)
+            self.logger.error(
+                "Incorrect permissions set on socket directory %s", socket_dir
+            )
             return None
         # Remove stale socket file.
         if os.path.exists(socket_path):
             try:
                 os.remove(socket_path)
-            except (PermissionError) as err:  # pytype: disable=name-error
-                self.logger.error('Unable to remove old socket: %s', err)
+            except PermissionError as err:  # pytype: disable=name-error
+                self.logger.error("Unable to remove old socket: %s", err)
                 return None
         return socket_path
