@@ -34,12 +34,12 @@ STACK_STATE_GONE = 4
 # Not stack port configured
 STACK_STATE_NONE = -1
 STACK_DISPLAY_DICT = {
-    STACK_STATE_ADMIN_DOWN: 'ADMIN_DOWN',
-    STACK_STATE_INIT: 'INITIALIZING',
-    STACK_STATE_BAD: 'BAD',
-    STACK_STATE_UP: 'UP',
-    STACK_STATE_GONE: 'GONE',
-    STACK_STATE_NONE: 'NONE'
+    STACK_STATE_ADMIN_DOWN: "ADMIN_DOWN",
+    STACK_STATE_INIT: "INITIALIZING",
+    STACK_STATE_BAD: "BAD",
+    STACK_STATE_UP: "UP",
+    STACK_STATE_GONE: "GONE",
+    STACK_STATE_NONE: "NONE",
 }
 
 # LACP not configured
@@ -53,11 +53,11 @@ LACP_ACTOR_UP = 3
 # LACP actor is not sending LACP with sync bit set
 LACP_ACTOR_NOSYNC = 5
 LACP_ACTOR_DISPLAY_DICT = {
-    LACP_ACTOR_NOTCONFIGURED: 'NOT_CONFIGURED',
-    LACP_ACTOR_NONE: 'NONE',
-    LACP_ACTOR_INIT: 'INITIALIZING',
-    LACP_ACTOR_UP: 'UP',
-    LACP_ACTOR_NOSYNC: 'NO_SYNC'
+    LACP_ACTOR_NOTCONFIGURED: "NOT_CONFIGURED",
+    LACP_ACTOR_NONE: "NONE",
+    LACP_ACTOR_INIT: "INITIALIZING",
+    LACP_ACTOR_UP: "UP",
+    LACP_ACTOR_NOSYNC: "NO_SYNC",
 }
 
 # LACP is not configured
@@ -69,10 +69,10 @@ LACP_PORT_SELECTED = 2
 # Port is a LACP port that is in standby
 LACP_PORT_STANDBY = 3
 LACP_PORT_DISPLAY_DICT = {
-    LACP_PORT_NOTCONFIGURED: 'NOT_CONFIGURED',
-    LACP_PORT_UNSELECTED: 'UNSELECTED',
-    LACP_PORT_SELECTED: 'SELECTED',
-    LACP_PORT_STANDBY: 'STANDBY'
+    LACP_PORT_NOTCONFIGURED: "NOT_CONFIGURED",
+    LACP_PORT_UNSELECTED: "UNSELECTED",
+    LACP_PORT_SELECTED: "SELECTED",
+    LACP_PORT_STANDBY: "STANDBY",
 }
 
 
@@ -80,147 +80,147 @@ class Port(Conf):
     """Stores state for ports, including the configuration."""
 
     defaults = {
-        'number': None,
-        'name': None,
-        'description': None,
-        'enabled': True,
-        'permanent_learn': False,
+        "number": None,
+        "name": None,
+        "description": None,
+        "enabled": True,
+        "permanent_learn": False,
         # if True, a host once learned on this port cannot be learned on another port.
-        'unicast_flood': True,
+        "unicast_flood": True,
         # if True, do classical unicast flooding on this port (False floods ND/ARP/bcast only).
-        'mirror': None,
+        "mirror": None,
         # If set, mirror packets from that port to this one.
-        'native_vlan': None,
+        "native_vlan": None,
         # Set untagged VLAN on this port.
-        'tagged_vlans': None,
+        "tagged_vlans": None,
         # Set tagged VLANs on this port.
-        'acl_in': None,
-        'acls_in': None,
+        "acl_in": None,
+        "acls_in": None,
         # ACL for input on this port.
-        'stack': None,
+        "stack": None,
         # Configure a stack peer on this port.
-        'max_hosts': 255,
+        "max_hosts": 255,
         # maximum number of hosts
-        'hairpin': False,
+        "hairpin": False,
         # if True, then switch unicast and flood between hosts on this port (eg WiFi radio).
-        'hairpin_unicast': False,
+        "hairpin_unicast": False,
         # if True, then switch unicast between hosts on this port (eg WiFi radio).
-        'lacp': 0,
+        "lacp": 0,
         # if non 0 (LAG ID), experimental LACP support enabled on this port.
-        'lacp_active': False,
+        "lacp_active": False,
         # experimental active LACP
-        'lacp_collect_and_distribute': False,
+        "lacp_collect_and_distribute": False,
         # if true, forces LACP port to collect and distribute when syncing with the peer.
-        'lacp_unselected': False,
+        "lacp_unselected": False,
         # if true, forces LACP port to be in unselected state
-        'lacp_selected': False,
+        "lacp_selected": False,
         # if true, forces LACP port to be in the selected state
-        'lacp_standby': False,
+        "lacp_standby": False,
         # if true, forces LACP port to be in the standby state
-        'lacp_passthrough': None,
+        "lacp_passthrough": None,
         # If set, fail the lacp on this port if any of the peer ports are down.
-        'lacp_resp_interval': 1,
+        "lacp_resp_interval": 1,
         # Min time since last LACP response. Used to control rate of response for LACP
-        'lacp_port_priority': 255,
+        "lacp_port_priority": 255,
         # Sets port priority value sent out in lacp packet
-        'lacp_port_id': -1,
+        "lacp_port_id": -1,
         # Sets port id value sent out in lacp packet
-        'loop_protect': False,
+        "loop_protect": False,
         # if True, do simple (host/access port) loop protection on this port.
-        'loop_protect_external': False,
+        "loop_protect_external": False,
         # if True, do external (other switch) loop protection on this port.
-        'output_only': False,
+        "output_only": False,
         # if True, all packets input from this port are dropped.
-        'lldp_beacon': {},
+        "lldp_beacon": {},
         # LLDP beacon configuration for this port.
-        'opstatus_reconf': True,
+        "opstatus_reconf": True,
         # If True, configure pipeline if operational status of port changes.
-        'receive_lldp': False,
+        "receive_lldp": False,
         # If True, receive LLDP on this port.
-        'lldp_peer_mac': None,
+        "lldp_peer_mac": None,
         # If set, validates src MAC address of incoming LLDP packets
-        'max_lldp_lost': 3,
+        "max_lldp_lost": 3,
         # threshold before marking a stack port as down
-        'dot1x': False,
+        "dot1x": False,
         # If true, block this port until a successful 802.1x auth
-        'dot1x_acl': False,
+        "dot1x_acl": False,
         # If true, expects authentication and default ACLs for 802.1x auth
-        'dot1x_mab': False,
+        "dot1x_mab": False,
         # If true, allows Mac Auth Bypass on port (NOTE: this is less secure as MACs can be spoofed)
-        'dot1x_dyn_acl': False,
+        "dot1x_dyn_acl": False,
         # If true, expects authentication and ACLs with dot1x_assigned flag set
-        'restricted_bcast_arpnd': False,
+        "restricted_bcast_arpnd": False,
         # If true, this port cannot send non-ARP/IPv6 ND broadcasts to other restricted_bcast_arpnd ports.
-        'coprocessor': {},
+        "coprocessor": {},
         # If defined, this port is attached to a packet coprocessor.
-        'count_untag_vlan_miss': False,
+        "count_untag_vlan_miss": False,
         # If defined, this port will explicitly count unconfigured native VLAN packets.
     }
 
     defaults_types = {
-        'number': int,
-        'name': str,
-        'description': str,
-        'enabled': bool,
-        'permanent_learn': bool,
-        'unicast_flood': bool,
-        'mirror': (list, str, int),
-        'native_vlan': (str, int),
-        'tagged_vlans': list,
-        'acl_in': (str, int),
-        'acls_in': list,
-        'stack': dict,
-        'max_hosts': int,
-        'hairpin': bool,
-        'hairpin_unicast': bool,
-        'lacp': int,
-        'lacp_active': bool,
-        'lacp_collect_and_distribute': bool,
-        'lacp_unselected': bool,
-        'lacp_selected': bool,
-        'lacp_standby': bool,
-        'lacp_passthrough': list,
-        'lacp_resp_interval': int,
-        'lacp_port_priority': int,
-        'lacp_port_id': int,
-        'loop_protect': bool,
-        'loop_protect_external': bool,
-        'output_only': bool,
-        'lldp_beacon': dict,
-        'opstatus_reconf': bool,
-        'receive_lldp': bool,
-        'lldp_peer_mac': str,
-        'dot1x': bool,
-        'dot1x_acl': bool,
-        'dot1x_mab': bool,
-        'dot1x_dyn_acl': bool,
-        'max_lldp_lost': int,
-        'restricted_bcast_arpnd': bool,
-        'coprocessor': dict,
-        'count_untag_vlan_miss': bool,
+        "number": int,
+        "name": str,
+        "description": str,
+        "enabled": bool,
+        "permanent_learn": bool,
+        "unicast_flood": bool,
+        "mirror": (list, str, int),
+        "native_vlan": (str, int),
+        "tagged_vlans": list,
+        "acl_in": (str, int),
+        "acls_in": list,
+        "stack": dict,
+        "max_hosts": int,
+        "hairpin": bool,
+        "hairpin_unicast": bool,
+        "lacp": int,
+        "lacp_active": bool,
+        "lacp_collect_and_distribute": bool,
+        "lacp_unselected": bool,
+        "lacp_selected": bool,
+        "lacp_standby": bool,
+        "lacp_passthrough": list,
+        "lacp_resp_interval": int,
+        "lacp_port_priority": int,
+        "lacp_port_id": int,
+        "loop_protect": bool,
+        "loop_protect_external": bool,
+        "output_only": bool,
+        "lldp_beacon": dict,
+        "opstatus_reconf": bool,
+        "receive_lldp": bool,
+        "lldp_peer_mac": str,
+        "dot1x": bool,
+        "dot1x_acl": bool,
+        "dot1x_mab": bool,
+        "dot1x_dyn_acl": bool,
+        "max_lldp_lost": int,
+        "restricted_bcast_arpnd": bool,
+        "coprocessor": dict,
+        "count_untag_vlan_miss": bool,
     }
 
     stack_defaults_types = {
-        'dp': str,
-        'port': (str, int),
+        "dp": str,
+        "port": (str, int),
     }
 
     lldp_beacon_defaults_types = {
-        'enable': bool,
-        'org_tlvs': list,
-        'system_name': str,
-        'port_descr': str,
+        "enable": bool,
+        "org_tlvs": list,
+        "system_name": str,
+        "port_descr": str,
     }
 
     lldp_org_tlv_defaults_types = {
-        'oui': (int, bytearray),
-        'subtype': (int, bytearray),
-        'info': (str, bytearray)
+        "oui": (int, bytearray),
+        "subtype": (int, bytearray),
+        "info": (str, bytearray),
     }
 
     coprocessor_defaults_types = {
-        'strategy': str,
-        'vlan_vid_base': int,
+        "strategy": str,
+        "vlan_vid_base": int,
     }
 
     def __init__(self, _id, dp_id, conf=None):
@@ -290,7 +290,7 @@ class Port(Conf):
             self.mirror = [self.mirror]
 
     def __str__(self):
-        return f'Port {self.number}'
+        return "Port %u" % self.number
 
     def __repr__(self):
         return self.__str__()
@@ -306,138 +306,187 @@ class Port(Conf):
             self.dyn_update_time = prev_port.dyn_update_time
 
     def stack_descr(self):
-        """"Return stacking annotation if this is a stacking port."""
+        """Return stacking annotation if this is a stacking port."""
         if self.stack:
-            return f'remote DP {self.stack["dp"].name} {self.stack["port"]}'
-        return ''
+            return "remote DP %s %s" % (self.stack["dp"].name, self.stack["port"])
+        return ""
 
     def set_defaults(self):
         super().set_defaults()
-        self._set_default('number', self._id)
-        self._set_default('name', str(self._id))
-        self._set_default('description', self.name)
-        self._set_default('tagged_vlans', [])
+        self._set_default("number", self._id)
+        self._set_default("name", str(self._id))
+        self._set_default("description", self.name)
+        self._set_default("tagged_vlans", [])
 
     def check_config(self):
         super().check_config()
-        test_config_condition(not (isinstance(self.number, int) and self.number > 0 and (
-            not valve_of.ignore_port(self.number))), (f'Port number invalid: {self.number}'))
-        non_vlan_options = {'stack', 'mirror', 'coprocessor', 'output_only'}
-        vlan_agnostic_options = {'enabled', 'number', 'name', 'description', 'max_lldp_lost'}
+        test_config_condition(
+            not (
+                isinstance(self.number, int)
+                and self.number > 0
+                and (not valve_of.ignore_port(self.number))
+            ),
+            ("Port number invalid: %s" % self.number),
+        )
+        non_vlan_options = {"stack", "mirror", "coprocessor", "output_only"}
+        vlan_agnostic_options = {
+            "enabled",
+            "number",
+            "name",
+            "description",
+            "max_lldp_lost",
+        }
         vlan_port = self.tagged_vlans or self.native_vlan
-        non_vlan_port_options = {option for option in non_vlan_options if getattr(self, option)}
+        non_vlan_port_options = {
+            option for option in non_vlan_options if getattr(self, option)
+        }
         test_config_condition(
             vlan_port and non_vlan_port_options,
-            f'cannot have VLANs configured on non-VLAN ports: {self}')
+            "cannot have VLANs configured on non-VLAN ports: %s" % self,
+        )
         if self.output_only:
             test_config_condition(
-                not non_vlan_port_options.issubset({'mirror', 'output_only'}),
-                f'output_only can only coexist with mirror option on same port {self}')
+                not non_vlan_port_options.issubset({"mirror", "output_only"}),
+                "output_only can only coexist with mirror option on same port %s"
+                % self,
+            )
         elif self.mirror:
             test_config_condition(
-                not non_vlan_port_options.issubset({'mirror', 'coprocessor'}),
-                f'coprocessor can only coexist with mirror option on same port {self}')
+                not non_vlan_port_options.issubset({"mirror", "coprocessor"}),
+                "coprocessor can only coexist with mirror option on same port %s"
+                % self,
+            )
         else:
             test_config_condition(
                 len(non_vlan_port_options) > 1,
-                f'cannot have multiple non-VLAN port options {non_vlan_port_options} on same port: {self}')
+                "cannot have multiple non-VLAN port options %s on same port: %s"
+                % (non_vlan_port_options, self),
+            )
         if non_vlan_port_options:
             for key, default_val in self.defaults.items():
                 if key in vlan_agnostic_options or key in non_vlan_port_options:
                     continue
-                if key.startswith('acl') and (self.stack or self.coprocessor):
+                if key.startswith("acl") and (self.stack or self.coprocessor):
                     continue
                 val = getattr(self, key)
                 test_config_condition(
                     val != default_val and val,
-                    f'Cannot have VLAN option {key}: {val} on non-VLAN port {self}')
+                    "Cannot have VLAN option %s: %s on non-VLAN port %s"
+                    % (key, val, self),
+                )
         test_config_condition(
             self.hairpin and self.hairpin_unicast,
-            'Cannot have both hairpin and hairpin_unicast enabled')
+            "Cannot have both hairpin and hairpin_unicast enabled",
+        )
         dot1x_features = {
-            dot1x_feature for dot1x_feature, dot1x_config in self.defaults.items()
-            if dot1x_feature.startswith('dot1x_') and dot1x_config}
+            dot1x_feature
+            for dot1x_feature, dot1x_config in self.defaults.items()
+            if dot1x_feature.startswith("dot1x_") and dot1x_config
+        }
         test_config_condition(
             dot1x_features and not self.dot1x,
-            f'802.1x features {dot1x_features} require port to have dot1x enabled')
+            "802.1x features %s require port to have dot1x enabled" % dot1x_features,
+        )
         if self.dot1x:
-            test_config_condition(self.number > 65535, (
-                '802.1x not supported on ports > 65535'))
+            test_config_condition(
+                self.number > 65535, ("802.1x not supported on ports > 65535")
+            )
             if self.dot1x_mab:
-                test_config_condition(self.dot1x_dyn_acl, (
-                    '802.1x_MAB cannot be used with 802.1x_DYN_ACL'))
+                test_config_condition(
+                    self.dot1x_dyn_acl,
+                    ("802.1x_MAB cannot be used with 802.1x_DYN_ACL"),
+                )
             if self.dot1x_dyn_acl:
-                test_config_condition(self.dot1x_acl, (
-                    '802.1x_DYN_ACL cannot be used with 802.1x_ACL'))
+                test_config_condition(
+                    self.dot1x_acl, ("802.1x_DYN_ACL cannot be used with 802.1x_ACL")
+                )
         if self.coprocessor:
             self._check_conf_types(self.coprocessor, self.coprocessor_defaults_types)
             test_config_condition(
-                self.coprocessor.get('strategy', None) != 'vlan_vid',
-                'coprocessor only supports vlan_vid strategy')
-            self.coprocessor['vlan_vid_base'] = self.coprocessor.get('vlan_vid_base', 1000)
+                self.coprocessor.get("strategy", None) != "vlan_vid",
+                "coprocessor only supports vlan_vid strategy",
+            )
+            self.coprocessor["vlan_vid_base"] = self.coprocessor.get(
+                "vlan_vid_base", 1000
+            )
         if self.stack:
             self._check_conf_types(self.stack, self.stack_defaults_types)
             for stack_config in list(self.stack_defaults_types.keys()):
-                test_config_condition(stack_config not in self.stack, (
-                    f'stack {stack_config} must be defined'))
+                test_config_condition(
+                    stack_config not in self.stack,
+                    ("stack %s must be defined" % stack_config),
+                )
             # LLDP always enabled for stack ports.
             self.receive_lldp = True
             if not self.lldp_beacon_enabled():
-                self.lldp_beacon.update({'enable': True})
+                self.lldp_beacon.update({"enable": True})
         if self.lacp_resp_interval is not None:
             test_config_condition(
                 self.lacp_resp_interval > 65535 or self.lacp_resp_interval < 0.3,
-                ('interval must be at least 0.3 and less than 65536'))
+                ("interval must be at least 0.3 and less than 65536"),
+            )
         if self.lacp_port_priority is not None:
             test_config_condition(
                 self.lacp_port_priority > 255 or self.lacp_port_priority < 0,
-                ('lacp port priority must be at least 0 and less than 256'))
+                ("lacp port priority must be at least 0 and less than 256"),
+            )
         if self.lldp_peer_mac:
-            test_config_condition(not netaddr.valid_mac(self.lldp_peer_mac), (
-                f'invalid MAC address {self.lldp_peer_mac}'))
+            test_config_condition(
+                not netaddr.valid_mac(self.lldp_peer_mac),
+                ("invalid MAC address %s" % self.lldp_peer_mac),
+            )
         if self.lldp_beacon:
-            self._check_conf_types(
-                self.lldp_beacon, self.lldp_beacon_defaults_types)
+            self._check_conf_types(self.lldp_beacon, self.lldp_beacon_defaults_types)
             self.lldp_beacon = self._set_unknown_conf(
-                self.lldp_beacon, self.lldp_beacon_defaults_types)
+                self.lldp_beacon, self.lldp_beacon_defaults_types
+            )
             if self.lldp_beacon_enabled():
-                if self.lldp_beacon['port_descr'] is None:
-                    self.lldp_beacon['port_descr'] = self.description
+                if self.lldp_beacon["port_descr"] is None:
+                    self.lldp_beacon["port_descr"] = self.description
                 org_tlvs = []
-                for org_tlv in self.lldp_beacon['org_tlvs']:
+                for org_tlv in self.lldp_beacon["org_tlvs"]:
                     self._check_conf_types(org_tlv, self.lldp_org_tlv_defaults_types)
-                    test_config_condition(len(org_tlv) != len(self.lldp_org_tlv_defaults_types), (
-                        'missing org_tlv config'))
-                    if not isinstance(org_tlv['info'], bytearray):
+                    test_config_condition(
+                        len(org_tlv) != len(self.lldp_org_tlv_defaults_types),
+                        ("missing org_tlv config"),
+                    )
+                    if not isinstance(org_tlv["info"], bytearray):
                         try:
-                            org_tlv['info'] = bytearray.fromhex(
-                                org_tlv['info'])  # pytype: disable=missing-parameter
+                            org_tlv["info"] = bytearray.fromhex(
+                                org_tlv["info"]
+                            )  # pytype: disable=missing-parameter
                         except ValueError:
-                            org_tlv['info'] = org_tlv['info'].encode('utf-8')
-                    if not isinstance(org_tlv['oui'], bytearray):
-                        org_tlv['oui'] = bytearray.fromhex(
-                            '%6.6x' % org_tlv['oui'])  # pytype: disable=missing-parameter
+                            org_tlv["info"] = org_tlv["info"].encode("utf-8")
+                    if not isinstance(org_tlv["oui"], bytearray):
+                        org_tlv["oui"] = bytearray.fromhex(
+                            "%6.6x" % org_tlv["oui"]
+                        )  # pytype: disable=missing-parameter
                     org_tlvs.append(org_tlv)
-                self.lldp_beacon['org_tlvs'] = org_tlvs
+                self.lldp_beacon["org_tlvs"] = org_tlvs
         test_config_condition(
             self.acl_in and self.acls_in,
-            'Found both acl_in and acls_in, use only acls_in')
+            "Found both acl_in and acls_in, use only acls_in",
+        )
         if self.acl_in and not isinstance(self.acl_in, list):
             self.acls_in = [self.acl_in]
             self.acl_in = None
         if self.acls_in:
             for acl in self.acls_in:
-                test_config_condition(not isinstance(acl, (int, str)),
-                                      'ACL names must be int or str')
+                test_config_condition(
+                    not isinstance(acl, (int, str)), "ACL names must be int or str"
+                )
         lacp_options = [self.lacp_selected, self.lacp_unselected, self.lacp_standby]
         test_config_condition(
             lacp_options.count(True) > 1,
-            'Cannot force multiple LACP port selection states')
+            "Cannot force multiple LACP port selection states",
+        )
 
     def finalize(self):
         if self.native_vlan:
-            test_config_condition(self.native_vlan in self.tagged_vlans, (
-                'cannot have same native and tagged VLAN on same port'))
+            test_config_condition(
+                self.native_vlan in self.tagged_vlans,
+                ("cannot have same native and tagged VLAN on same port"),
+            )
         self.tagged_vlans = tuple(self.tagged_vlans)
         super().finalize()
 
@@ -448,7 +497,11 @@ class Port(Conf):
     def vlans(self):
         """Return all VLANs this port is in."""
         if self.native_vlan is not None and self.dyn_dot1x_native_vlan is not None:
-            return (self.native_vlan,) + (self.dyn_dot1x_native_vlan,) + tuple(self.tagged_vlans)
+            return (
+                (self.native_vlan,)
+                + (self.dyn_dot1x_native_vlan,)
+                + tuple(self.tagged_vlans)
+            )
         if self.dyn_dot1x_native_vlan is not None:
             return (self.dyn_dot1x_native_vlan,) + tuple(self.tagged_vlans)
         if self.native_vlan is not None:
@@ -475,7 +528,7 @@ class Port(Conf):
 
     def lldp_beacon_enabled(self):
         """Return True if LLDP beacon enabled on this port."""
-        return self.lldp_beacon and self.lldp_beacon.get('enable', False)
+        return self.lldp_beacon and self.lldp_beacon.get("enable", False)
 
     def mirror_actions(self):
         """Return OF actions to mirror this port."""
@@ -682,24 +735,24 @@ class Port(Conf):
             int: Current (new) stack port state
             string: reason for the state change and additional information
         """
-        reason = ''
+        reason = ""
         if self.is_stack_admin_down():
             # Stack port ADMIN_DOWN, so no next state
             return self.stack_state()
 
-        last_seen_lldp_time = self.dyn_stack_probe_info.get('last_seen_lldp_time', None)
+        last_seen_lldp_time = self.dyn_stack_probe_info.get("last_seen_lldp_time", None)
         if last_seen_lldp_time is None:
             if self.is_stack_none():
                 # New stack, changing to state INIT
                 self.stack_init()
-                reason = 'new'
+                reason = "new"
         else:
             # Not a new stack port, so progess through state machine
-            peer_dp = self.stack['dp']  # pytype: disable=attribute-error
-            stack_correct = self.dyn_stack_probe_info.get(
-                'stack_correct', None)
+            peer_dp = self.stack["dp"]  # pytype: disable=attribute-error
+            stack_correct = self.dyn_stack_probe_info.get("stack_correct", None)
             send_interval = peer_dp.lldp_beacon.get(
-                'send_interval', peer_dp.DEFAULT_LLDP_SEND_INTERVAL)
+                "send_interval", peer_dp.DEFAULT_LLDP_SEND_INTERVAL
+            )
             time_since_lldp_seen = None
             num_lost_lldp = None
             stack_timed_out = True
@@ -712,15 +765,18 @@ class Port(Conf):
             if stack_timed_out:
                 # Stack timed out, too many packets lost
                 self.stack_gone()
-                reason = f'too many ({num_lost_lldp}) packets lost, last received {time_since_lldp_seen}s ago'
+                reason = "too many (%u) packets lost, last received %us ago" % (
+                    num_lost_lldp,
+                    time_since_lldp_seen,
+                )
             elif not stack_correct:
                 # Stack bad due to incorrect cabling
                 self.stack_bad()
-                reason = 'incorrect cabling'
+                reason = "incorrect cabling"
             elif not self.is_stack_up():
                 # Nothing gone wrong, so Stack UP
                 self.stack_up()
-                reason = 'up'
+                reason = "up"
         return self.stack_state(), reason
 
     def is_stack_admin_down(self):
